==> likewise-open_5.4.0.42111.orig.tar.gz: likewise-open-5.4.0.42111/srvsvc/server/includes.h <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Centeris Corporation 2004-2007
 * Copyright (C) Likewise Software 2007
 * All rights reserved.
 *
 * SrvSvc Server
 *
 */
#include <config.h>
#include <srvsvcsys.h>

#include <lw/winerror.h>
#include <lw/ntstatus.h>
#include <wc16str.h>
#include <lwmem.h>
#include <lwstr.h>
#include <lwerror.h>
#include <lwdscache.h>
#include <lw/base.h>
#include <lwio/lwio.h>
#include <lwio/ntfileapi.h>
#include <lwio/lmshare.h>
#include <lwio/lwshareinfo.h>
#include <dce/rpc.h>
#include <compat/dcerpc.h>
#include <lwrpc/lsa.h>
#include <lwnet.h>

#include <srvsvc/srvsvc.h>
#include <srvsvcdefs.h>
#include <srvsvcutils.h>

#include <srvsvclog_r.h>

#include "srvsvc.h"
#include "srvsvc_srv.h"
#include "srvsvc_h.h"

#include "wkssvc.h"
#include "wkssvc_srv.h"
#include "wkssvc_h.h"

#include "winreg.h"
#include "winreg_srv.h"
#include "winreg_h.h"

#include "defs.h"
#include "structs.h"
#include "prototypes.h"
#include "marshall.h"

#include "externs.h"


/*
local variables:
mode: c
c-basic-offset: 4
indent-tabs-mode: nil
tab-width: 4
end:
*/

==> likewise-open_6.0.0.53010.orig.tar.gz: likewise-open-6.0.0.53010/srvsvc/server/includes.h <==
/* Editor Settings: expandtabs and use 4 spaces for indentation
 * ex: set softtabstop=4 tabstop=8 expandtab shiftwidth=4: *
 */

/*
 * Copyright Likewise Software    2004-2008
 * All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 * or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * for more details.  You should have received a copy of the GNU General
 * Public License along with this program.  If not, see
 * <http://www.gnu.org/licenses/>.
 *
 * LIKEWISE SOFTWARE MAKES THIS SOFTWARE AVAILABLE UNDER OTHER LICENSING
 * TERMS AS WELL.  IF YOU HAVE ENTERED INTO A SEPARATE LICENSE AGREEMENT
 * WITH LIKEWISE SOFTWARE, THEN YOU MAY ELECT TO USE THE SOFTWARE UNDER THE
 * TERMS OF THAT SOFTWARE LICENSE AGREEMENT INSTEAD OF THE TERMS OF THE GNU
 * GENERAL PUBLIC LICENSE, NOTWITHSTANDING THE ABOVE NOTICE.  IF YOU
 * HAVE QUESTIONS, OR WISH TO REQUEST A COPY OF THE ALTERNATE LICENSING
 * TERMS OFFERED BY LIKEWISE SOFTWARE, PLEASE CONTACT LIKEWISE SOFTWARE AT
 * license@likewisesoftware.com
 */

/*
 * Copyright (C) Centeris Corporation 2004-2007
 * Copyright (C) Likewise Software 2007
 * All rights reserved.
 *
 * SrvSvc Server
 *
 */
#include <config.h>
#include <srvsvcsys.h>

#include <lw/winerror.h>
#include <lw/ntstatus.h>
#include <wc16str.h>
#include <lwmem.h>
#include <lwstr.h>
#include <lwerror.h>
#include <lwdscache.h>
#include <lw/base.h>
#include <lwio/lwio.h>
#include <lwio/ntfileapi.h>
#include <lwio/lwiodevctl.h>
#include <lwio/lmshare.h>
#include <lwio/lwshareinfo.h>
#include <lwio/lmsession.h>
#include <lwio/lwsessioninfo.h>
#include <lwio/lmfile.h>
#include <lwio/lwfileinfo.h>
#include <dce/rpc.h>
#include <compat/dcerpc.h>
#include <lw/rpc/lsa.h>
#include <lwnet.h>
#include <lw/rpc/lsa.h>

#include <lw/srvsvc.h>
#include <lw/winreg.h>

#include <srvsvcdefs.h>
#include <srvsvcutils.h>

#include <srvsvclog_r.h>

#include "srvsvc_srv.h"
#include "srvsvc_h.h"

#include "winreg.h"
#include "winreg_srv.h"
#include "winreg_h.h"

#include "defs.h"
#include "structs.h"
#include "prototypes.h"
#include "marshall.h"

#include "externs.h"


/*
local variables:
mode: c
c-basic-offset: 4
indent-tabs-mode: nil
tab-width: 4
end:
*/
